//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[Point](index.md)

# Point

interface [Point](index.md)

#### Inheritors

| |
|---|
| [ParentPoint](../-parent-point/index.md) |
| [ChildPoint](../-child-point/index.md) |

## Properties

| Name | Summary |
|---|---|
| [ron](ron.md) | [common]<br>abstract val [ron](ron.md): [ULong](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-u-long/index.html)<br>荣和点数 |
| [tsumoTotal](tsumo-total.md) | [common]<br>abstract val [tsumoTotal](tsumo-total.md): [ULong](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-u-long/index.html)<br>自摸总点数 |
